summaryrefslogtreecommitdiffstats
path: root/nixos
diff options
context:
space:
mode:
authorFlorian Jacob <projects+git@florianjacob.de>2018-11-13 19:05:30 +0100
committerFlorian Jacob <projects+git@florianjacob.de>2018-11-13 19:21:02 +0100
commite80cdb2bac7dc9dec58bd7fbe76a7ae9dfda782e (patch)
tree6f5750aec6093b23b698767a5f60fc2ef4144e67 /nixos
parentfd66e543aee269f24e8ebfed39800a05e2e3d99e (diff)
nixos/systemd-resolved: link resolv.conf to dynamic stub resolver
version as recommended by upstream (since systemd 236): https://www.freedesktop.org/software/systemd/man/systemd-resolved.html#/etc/resolv.conf
Diffstat (limited to 'nixos')
-rw-r--r--nixos/modules/config/networking.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/nixos/modules/config/networking.nix b/nixos/modules/config/networking.nix
index 627cce67e97d..e6b49d4c2194 100644
--- a/nixos/modules/config/networking.nix
+++ b/nixos/modules/config/networking.nix
@@ -260,9 +260,9 @@ in
'';
} // optionalAttrs config.services.resolved.enable {
# symlink the static version of resolv.conf as recommended by upstream:
# https://www.freedesktop.org/software/systemd/man/systemd-resolved.html#/etc/resolv.conf
- "resolv.conf".source = "${pkgs.systemd}/lib/systemd/resolv.conf";
+ "resolv.conf".source = "/run/systemd/resolve/stub-resolv.conf";
} // optionalAttrs (config.services.resolved.enable && dnsmasqResolve) {
"dnsmasq-resolv.conf".source = "/run/systemd/resolve/resolv.conf";
} // optionalAttrs (pkgs.stdenv.hostPlatform.libc == "glibc") {
@@ -260,9 +260,9 @@ in
'';
} // optionalAttrs config.services.resolved.enable {
- # symlink the static version of resolv.conf as recommended by upstream:
+ # symlink the dynamic stub resolver of resolv.conf as recommended by upstream:
# https://www.freedesktop.org/software/systemd/man/systemd-resolved.html#/etc/resolv.conf